@@ -15,8 +15,6 @@ layerNames <- function(x) {
 }
 
 
-
-
 .compare <- function(x, ..., extent=TRUE, rowcol=TRUE, crs=TRUE, res=FALSE, orig=FALSE, rotation=TRUE, tolerance, stopiffalse=TRUE, showwarning=FALSE) {
 	if (.depracatedwarnings()) {
 		warning("raster function 'compare' is obsolete. It has been replaced by 'compareRaster'")
@@ -25,17 +23,6 @@ layerNames <- function(x) {
 }
 
 
-if (!isGeneric("expand")) {
-	setGeneric("expand", function(x, y, ...)
-		standardGeneric("expand"))
-}	
-
-setMethod('expand', signature(x='Raster'), 
-function(x, y, value=NA, filename='', ...) {
-	stop("function 'expand' is obsolete. It has been replaced by 'extend'")
-} )
-
-
 setOptions <- function(...) {
 	if (.depracatedwarnings()) {
 		warning('this function is depracated. Use "rasterOptions" instead')
