@@ -1,7 +1,7 @@
 # raster package
-# Authors: Robert J. Hijmans, r.hijmans@gmail.com
+# Authors: Robert J. Hijmans
 # Date : September 2009
-# Version 0.9
+# Version 1.0
 # Licence GPL v3
 
 
@@ -14,11 +14,15 @@ if (!isGeneric("minValue")) {
 setMethod('minValue', signature(x='RasterLayer'), 
 	function(x, layer=-1, warn=TRUE) {
 		if ( x@data@haveminmax ) {
-			if (! inMemory(x) ) {
-				return(x@data@min * x@data@gain + x@data@offset)
+			v <- x@data@min
+			if (isTRUE( v == Inf)) {
+				v <- NA
 			} else {
-				return(x@data@min)
+				if (! inMemory(x) ) {
+					v <- v * x@data@gain + x@data@offset
+				}
 			}
+			return(v)
 		} else {
 			if (warn) warning('min value not known, use setMinMax')
 			return(NA)
@@ -29,21 +33,24 @@ setMethod('minValue', signature(x='RasterLayer'),
 
 setMethod('minValue', signature(x='RasterBrick'), 
 	function(x, layer=-1, warn=FALSE) {
-		layer <- round(layer)
+		layer <- round(layer)[1]
 		if (layer < 1) { 
 			if ( x@data@haveminmax ) {
+				v <- x@data@min
+				v[v == Inf] <- NA
 				if (! inMemory(x) ) {
-					return(x@data@min * x@data@gain + x@data@offset)
-				} else {
-					return(x@data@min)				
-				}
+					v <- v * x@data@gain + x@data@offset
+				}	
+				return(v)
 			} else {
 				warning('min value not known, use setMinMax')
 				return(rep(NA, nlayers(x)))
 			}
 		} else {
 			if ( x@data@haveminmax ) {
-				return(x@data@min[layer] * x@data@gain + x@data@offset)
+				v <- x@data@min[layer] * x@data@gain + x@data@offset
+				v[v == Inf] <- NA
+				return(v)
 			} else {
 				warning('min value not known, use setMinMax')
 				return(NA)
@@ -55,20 +62,21 @@ setMethod('minValue', signature(x='RasterBrick'),
 
 setMethod('minValue', signature(x='RasterStack'), 
 	function(x, layer=-1, warn=FALSE) {
-		layer <- round(layer)
+		layer <- round(layer)[1]
+		nl <- nlayers(x)
 		if (layer < 1) { 
-			minv <- vector()
-			for (i in 1:nlayers(x)) {
-				minv[i] <- minValue(x@layers[[i]], warn=FALSE)
+			v <- vector(length=nl)
+			for (i in 1:nl) {
+				v[i] <- minValue(x@layers[[i]], warn=warn)
 			}		
 		} else {
-			if (layer > 0 & layer <= nlayers(x)) {
-				minv <- minValue(x@layers[[layer]])
+			if (layer <= nl) {
+				v <- minValue(x@layers[[layer]])
 			} else {
 				stop('incorrect layer number')
 			}
 		}
-		return(minv)
+		return(v)
 	}
 )
 
@@ -82,8 +90,18 @@ if (!isGeneric("maxValue")) {
 
 setMethod('maxValue', signature(x='RasterLayer'), 
 	function(x, layer=-1, warn=TRUE) {
+
 		if ( x@data@haveminmax ) {
-			return(x@data@max * x@data@gain + x@data@offset)
+			v <- x@data@max
+			if (isTRUE( v == Inf)) {
+				v <- NA
+			} else {
+				if (! inMemory(x) ) {
+					v <- v * x@data@gain + x@data@offset
+				}
+			}
+			return(v)
+			
 		} else {
 			if (warn) warning('max value not known, use setMinMax')
 			return(NA)
@@ -93,43 +111,50 @@ setMethod('maxValue', signature(x='RasterLayer'),
 
 setMethod('maxValue', signature(x='RasterBrick'), 
 	function(x, layer=-1, warn=FALSE) {
-		layer <- round(layer)
-		if (layer < 1) { 
-			if ( x@data@haveminmax ) {
-				return(x@data@max * x@data@gain + x@data@offset)
-			} else {
-				warning('max value not known, use setMinMax')
-				return(rep(NA, nlayers(x)))
-			}
+	
+		if ( x@data@haveminmax ) {
+			v <- x@data@max
+			v[v == Inf] <- NA
+			if (! inMemory(x) ) {
+				v <- v * x@data@gain + x@data@offset
+			}	
+			return(v)
 		} else {
-			if ( x@data@haveminmax ) {
-				return(x@data@max[layer] * x@data@gain + x@data@offset)
+			if (warn) warning('max value not known, use setMinMax')
+			v <- rep(NA, nlayers(x))
+		}
+		layer <- round(layer)[1]
+		if (layer > 0) {
+			if (layer <= nlayers(x)) {
+				v <- v[layer]
 			} else {
-				warning('max value not known, use setMinMax')
-				return(NA)
+				stop('invalid layer selected')
 			}
 		}
+		return(v)
 	}
 )
 
 
+		
+
 setMethod('maxValue', signature(x='RasterStack'), 
 	function(x, layer=-1, warn=FALSE) {
-		layer <- round(layer)
+		layer <- round(layer)[1]
+		nl <- nlayers(x)
 		if (layer < 1) { 
-			maxv <- vector()
-			for (i in 1:nlayers(x)) {
-				maxv[i] <- maxValue(x@layers[[i]], warn=FALSE)
+			v <- vector(length=nl)
+			for (i in 1:nl) {
+				v[i] <- maxValue(x@layers[[i]], warn=warn)
 			}		
 		} else {
-			if (layer > 0 & layer <= nlayers(x)) {
-				maxv <- maxValue(x@layers[[layer]])
+			if (layer <= nl) {
+				v <- maxValue(x@layers[[layer]])
 			} else {
 				stop('incorrect layer number')
 			}
 		}
-		return(maxv)
+		return(v)
 	}
 )
 
-		
