@@ -438,3 +438,12 @@ setMethod('raster', signature(x='grf'),
 	}
 )
 
+
+
+setMethod('raster', signature(x='GridTopology'),
+	# contributed by Michael Sumner
+	function(x) {
+		raster(extent(x))
+	}
+)
+
