@@ -28,7 +28,7 @@
 			if (length(uniquecells) > 250 & canProcessInMemory(x, 4)) {
 				vals <- getValues(x)
 				if (length(layers) > 1) {
-					vals <- vals[uniquecells, layers]
+					vals <- vals[uniquecells, layers, drop=FALSE]
 				} else {
 					vals <- vals[uniquecells]				
 				}
@@ -55,7 +55,7 @@
 	}
 	
 	if (is.null(dim(vals))) { 
-		vals <- matrix(vals, ncol=1)
+		vals <- matrix(vals, ncol=length(layers))
 		colnames(vals) <- names(x)[layers]
 	}
 		
@@ -207,12 +207,18 @@
 	signed <- dataSigned(x@file@datanotation)
 	if (dsize > 2) { signed <- TRUE }
 	
-	x <- openConnection(x)
+	is.open <- x@file@open
+	if (!is.open) {
+		x <- readStart(x)
+	}
+
 	for (i in seq(along=cells)) {
 		seek(x@file@con, cells[i])
 		res[i] <- readBin(x@file@con, what=dtype, n=1, size=dsize, endian=byteord, signed=signed) 
 	}
-	x <- closeConnection(x)
+	if (!is.open) {
+		x <- readStop(x)
+	}
 	
 	if (x@file@datanotation == 'INT4U') {
 		i <- !is.na(res) & res < 0
