@@ -27,7 +27,7 @@ setMethod('rotate', signature(x='Raster'),
 		r2 <- crop(x, extent(hx, e@xmax, e@ymin, e@ymax))
 		if (inverse) {
 			r1@extent@xmin <- r2@extent@xmax
-			r1@extent@xmax <- r1@extent@xmin + xrange
+			r1@extent@xmax <- r1@extent@xmin + 0.5 * xrange
 		} else {
 			r2@extent@xmin <- r2@extent@xmin - xrange
 			r2@extent@xmax <- r2@extent@xmax - xrange
